join

package
v0.0.0-...-c89b0e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 19, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package join provide an example of interface and type switch.

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func Join

func Join(sep string, a ...interface{}) string

Join concatenates the elements of a to create a single string. The separator sep is placed between each element.

Example
t := task.Task{
	Title:    "Laundry",
	Status:   task.DONE,
	Deadline: nil,
}
fmt.Println(Join(",", 1, "two", 3, t))
Output:
1,two,3,[v] Laundry <nil>

Types

This section is empty.

Jump to